@@ -13,7 +13,7 @@ install_environment = helpers.no_install
 
 
 def run_hook(
-        hook: 'Hook',
+        hook: Hook,
         file_args: Sequence[str],
         color: bool,
 ) -> Tuple[int, bytes]:  # pragma: windows no cover
